@@ -2,7 +2,7 @@ var searchData=
 [
   ['libevdev_5fgrab_5fmode',['libevdev_grab_mode',['../group__init.html#gaa282ec9badaa6bc11b1dc5bb124dbd5b',1,'libevdev.h']]],
   ['libevdev_5fled_5fvalue',['libevdev_led_value',['../group__kernel.html#ga8cddf7779debef0067665671e911ec41',1,'libevdev.h']]],
-  ['libevdev_5flog_5fpriority',['libevdev_log_priority',['../group__init.html#ga0b798d0864f2b1b10e4603f9431b3364',1,'libevdev.h']]],
+  ['libevdev_5flog_5fpriority',['libevdev_log_priority',['../group__logging.html#ga0b798d0864f2b1b10e4603f9431b3364',1,'libevdev.h']]],
   ['libevdev_5fread_5fflag',['libevdev_read_flag',['../group__events.html#ga56c288d9f2e4c1632986c4e218c494e9',1,'libevdev.h']]],
   ['libevdev_5fread_5fstatus',['libevdev_read_status',['../group__events.html#ga4a96221b3c7f54dfb86035d952154e3a',1,'libevdev.h']]],
   ['libevdev_5fuinput_5fopen_5fmode',['libevdev_uinput_open_mode',['../libevdev-uinput_8h.html#a6546acd3e4fe75a74d91eebf9bbd3d03',1,'libevdev-uinput.h']]]
