@@ -101,9 +101,10 @@ extern "C" {
  *
  *      kernel → libevdev → xf86-input-evdev → X server → X client
  *
- * For Weston/Wayland, the stack would look like this:
+ * For anything using libinput (e.g. most Wayland compositors), the stack
+ * the stack would look like this:
  *
- *      kernel → libevdev → Weston → Wayland client
+ *      kernel → libevdev → libinput → Compositor → Wayland client
  *
  * libevdev does **not** have knowledge of X clients or Wayland clients, it is
  * too low in the stack.
@@ -161,9 +162,13 @@ extern "C" {
  * libevdev is licensed under the
  * [X11 license](http://cgit.freedesktop.org/libevdev/tree/COPYING).
  *
+ * Bindings
+ * ===================
+ * - Python: https://gitlab.freedesktop.org/libevdev/python-libevdev
+ *
  * Reporting bugs
  * ==============
- * Please report bugs in the freedesktop.org GitLab:
+ * Please report bugs in the freedesktop.org GitLab instance:
  * https://gitlab.freedesktop.org/libevdev/libevdev/issues/
  */
 
@@ -688,7 +693,7 @@ extern "C" {
  * meaning, matching the axis names in linux/input.h. Some devices merely
  * export a number of axes beyond the available axis list. For those
  * devices, the multitouch information is invalid. Specifically, if a device
- * provides the ABS_MT_SLOT axis AND also the (ABS_MT_SLOT - 1) axis, the
+ * provides the ABS_MT_SLOT axis AND also the ABS_RESERVED axis, the
  * device is not treated as multitouch device. No slot information is
  * available and the ABS_MT axis range for these devices is treated as all
  * other EV_ABS axes.
@@ -802,7 +807,7 @@ int libevdev_new_from_fd(int fd, struct libevdev **dev);
  * libevdev</code> is invalid and must not be used.
  *
  * Note that calling libevdev_free() does not close the file descriptor
- * currently asssociated with this instance.
+ * currently associated with this instance.
  *
  * @param dev The evdev device
  *
@@ -1267,7 +1272,9 @@ int libevdev_get_id_product(const struct libevdev *dev);
  * @param product_id The product ID to assign to this device
  *
  * @note This function may be called before libevdev_set_fd(). A call to
- * libevdev_set_fd() will overwrite any previously set value.
+ * libevdev_set_fd() will overwrite any previously set value. Even though
+ * the function accepts an int for product_id the value is truncated at 16
+ * bits.
  */
 void libevdev_set_id_product(struct libevdev *dev, int product_id);
 
@@ -1289,7 +1296,9 @@ int libevdev_get_id_vendor(const struct libevdev *dev);
  * @param vendor_id The vendor ID to assign to this device
  *
  * @note This function may be called before libevdev_set_fd(). A call to
- * libevdev_set_fd() will overwrite any previously set value.
+ * libevdev_set_fd() will overwrite any previously set value. Even though
+ * the function accepts an int for vendor_id the value is truncated at 16
+ * bits.
  */
 void libevdev_set_id_vendor(struct libevdev *dev, int vendor_id);
 
@@ -1311,7 +1320,9 @@ int libevdev_get_id_bustype(const struct libevdev *dev);
  * @param bustype The bustype to assign to this device
  *
  * @note This function may be called before libevdev_set_fd(). A call to
- * libevdev_set_fd() will overwrite any previously set value.
+ * libevdev_set_fd() will overwrite any previously set value. Even though
+ * the function accepts an int for bustype the value is truncated at 16
+ * bits.
  */
 void libevdev_set_id_bustype(struct libevdev *dev, int bustype);
 
@@ -1333,7 +1344,9 @@ int libevdev_get_id_version(const struct libevdev *dev);
  * @param version The version to assign to this device
  *
  * @note This function may be called before libevdev_set_fd(). A call to
- * libevdev_set_fd() will overwrite any previously set value.
+ * libevdev_set_fd() will overwrite any previously set value. Even though
+ * the function accepts an int for version the value is truncated at 16
+ * bits.
  */
 void libevdev_set_id_version(struct libevdev *dev, int version);
 
@@ -1531,9 +1544,12 @@ int libevdev_get_event_value(const struct libevdev *dev, unsigned int type, unsi
  * @param value The new value to set
  *
  * @return 0 on success, or -1 on failure.
- * @retval -1 the device does not have the event type or code enabled, or the code is outside the
- * allowed limits for the given type, or the type cannot be set, or the
- * value is not permitted for the given code.
+ * @retval -1
+ * - the device does not have the event type or
+ * - code enabled, or the code is outside the, or
+ * - the code is outside the allowed limits for the given type, or
+ * - the type cannot be set, or
+ * - the value is not permitted for the given code.
  *
  * @see libevdev_set_slot_value
  * @see libevdev_get_event_value
@@ -1608,9 +1624,11 @@ int libevdev_get_slot_value(const struct libevdev *dev, unsigned int slot, unsig
  * @param value The new value to set
  *
  * @return 0 on success, or -1 on failure.
- * @retval -1 the device does not have the event code enabled, or the code is
- * outside the allowed limits for multitouch events, or the slot number is outside
- * the limits for this device, or the device does not support multitouch events.
+ * @retval -1
+ * - the device does not have the event code enabled, or
+ * - the code is outside the allowed limits for multitouch events, or
+ * - the slot number is outside the limits for this device, or
+ * - the device does not support multitouch events.
  *
  * @see libevdev_set_event_value
  * @see libevdev_get_slot_value
@@ -2174,6 +2192,86 @@ int libevdev_event_code_from_name_n(unsigned int type, const char *name,
 int libevdev_event_value_from_name(unsigned int type, unsigned int code,
 				   const char *name);
 
+/**
+ * @ingroup misc
+ *
+ * Look up an event type for a  event code name. For example, the name
+ * "ABS_Y" returns EV_ABS. For the lookup to succeed, the name must be
+ * unique, which is the case for all defines as of kernel 5.0 and likely to
+ * be the case in the future.
+ *
+ * This is equivalent to libevdev_event_type_from_name() but takes the code
+ * name instead of the type name.
+ *
+ * @param name A non-NULL string describing an input-event value
+ * ("ABS_X", "REL_Y", "KEY_A", ...)
+ *
+ * @return The given event code for the name or -1 if not found.
+ */
+int
+libevdev_event_type_from_code_name(const char *name);
+
+/**
+ * @ingroup misc
+ *
+ * Look up an event type for a  event code name. For example, the name
+ * "ABS_Y" returns EV_ABS. For the lookup to succeed, the name must be
+ * unique, which is the case for all defines as of kernel 5.0 and likely to
+ * be the case in the future.
+ *
+ * This is equivalent to libevdev_event_type_from_name_n() but takes the code
+ * name instead of the type name.
+ *
+ * @param name A non-NULL string describing an input-event value
+ * ("ABS_X", "REL_Y", "KEY_A", ...)
+ * @param len The length of the passed string excluding any terminating 0
+ * character.
+ *
+ * @return The given event code for the name or -1 if not found.
+ */
+int
+libevdev_event_type_from_code_name_n(const char *name, size_t len);
+
+/**
+ * @ingroup misc
+ *
+ * Look up an event code by its name. For example, the name "ABS_Y"
+ * returns 1. For the lookup to succeed, the name must be unique, which is
+ * the case for all defines as of kernel 5.0 and likely to be the case in
+ * the future.
+ *
+ * This is equivalent to libevdev_event_code_from_name() without the need
+ * for knowing the event type.
+ *
+ * @param name A non-NULL string describing an input-event value
+ * ("ABS_X", "REL_Y", "KEY_A", ...)
+ *
+ * @return The given event code for the name or -1 if not found.
+ */
+int
+libevdev_event_code_from_code_name(const char *name);
+
+/**
+ * @ingroup misc
+ *
+ * Look up an event code by its name. For example, the name "ABS_Y"
+ * returns 1. For the lookup to succeed, the name must be unique, which is
+ * the case for all defines as of kernel 5.0 and likely to be the case in
+ * the future.
+ *
+ * This is equivalent to libevdev_event_code_from_name_n() without the need
+ * for knowing the event type.
+ *
+ * @param name A non-NULL string describing an input-event value
+ * ("ABS_X", "REL_Y", "KEY_A", ...)
+ * @param len The length of the passed string excluding any terminating 0
+ * character.
+ *
+ * @return The given event code for the name or -1 if not found.
+ */
+int
+libevdev_event_code_from_code_name_n(const char *name, size_t len);
+
 /**
  * @ingroup misc
  *
